# Copyright 2019 Xanadu Quantum Technologies Inc.

# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at

#     http://www.apache.org/licenses/LICENSE-2.0

# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

#!/usr/bin/env python3
import sys
import os
from setuptools import setup
# from sphinx.setup_command import BuildDoc

with open("blackbird_python/blackbird/_version.py") as f:
	version = f.readlines()[-1].split()[-1].strip("\"'")

requirements = [
    "numpy>=1.16",
    "sympy",
    "antlr4-python3-runtime==4.8",
    "networkx"
]

info = {
    'name': 'quantum-blackbird',
    'version': version,
    'maintainer': 'Xanadu Inc.',
    'maintainer_email': 'josh@xanadu.ai',
    'url': 'https://github.com/XanaduAI/blackbird',
    'license': 'Apache License 2.0',
    'packages': [
                    'blackbird'
                ],
    'package_dir': {'': 'blackbird_python'},
    'description': 'Blackbird is a quantum assembly language for continuous-variable quantum computation by Xanadu Inc.',
    'long_description': open('README.rst').read(),
    'provides': ["blackbird"],
    'install_requires': requirements
}

classifiers = [
    "Development Status :: 4 - Beta",
    "Environment :: Console",
    "Intended Audience :: Science/Research",
    "License :: OSI Approved :: Apache Software License",
    "Natural Language :: English",
    "Operating System :: POSIX",
    "Operating System :: MacOS :: MacOS X",
    "Operating System :: POSIX :: Linux",
    "Operating System :: Microsoft :: Windows",
    "Programming Language :: Python",
    'Programming Language :: Python :: 3',
    'Programming Language :: Python :: 3.5',
    'Programming Language :: Python :: 3.6',
    'Programming Language :: Python :: 3.7',
    'Programming Language :: Python :: 3 :: Only',
    "Topic :: Scientific/Engineering :: Physics"
]

setup(classifiers=classifiers, **(info))
